@@ -1,6 +1,10 @@
+import glob
 from markdown import markdown
 
 def joke():
     return markdown(u'Wenn ist das Nunst\u00fcck git und Slotermeyer?'
                     u'Ja! ... **Beiherhund** das Oder die Flipperwaldt '
                     u'gersput.')
+
+def checkfile():
+    print(glob.glob("./samples/*"))
